<?php

if ( !defined( 'ABSPATH' ) ) exit;

class simple_price_list_920_settings {
    private $options;

    public function __construct() {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page() {
        add_options_page(
            'Settings Admin', 
            __('Simple price list settings', 'simple-price-list'), 
            'manage_options', 
            'simple-price-list-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page() {
        $this->options = simple_price_list_920_get_options();
        $tabs = array('setup', 'shortcode');
        $text = __('setup tab', 'simple-price-list');
        $text = __('shortcode tab', 'simple-price-list');
        ?>
        <style>.form-table td {padding: 0px 10px 0 10px;}</style>
        <div class="wrap">
            <h1><?php echo __('Simple price list settings', 'simple-price-list');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'simple-price-list-tab' ] ) ? sanitize_text_field($_GET[ 'simple-price-list-tab' ]) : 'setup';
            ?>
            <h2 class="nav-tab-wrapper">
                <?php for ($i = 0; $i <= count($tabs)-1; $i++) { ?>
                    <a href="<?php echo get_admin_url();?>options-general.php?page=simple-price-list-setting-admin&simple-price-list-tab=<?php echo $tabs[$i];?>" class="nav-tab  <?php echo $active_tab == $tabs[$i] ? 'nav-tab-active' : ''; ?>"><?php echo __($tabs[$i] .' tab', 'simple-price-list');?></a>
                <?php } ?>
            </h2>
            <div class="simple-price-list-setting-page">
                <div>
            <?php
                switch ($active_tab){ 

                    case 'setup':
                        ?>
                        <form method="post" action="options.php">
                        <?php
                            settings_fields( 'simple_price_list_option_main' );
                            do_settings_sections( 'simple-price-list-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <?php
                        break;

                    default: 
                        simple_price_list_920_include('/libs/admin/'.$active_tab.'.php');
                }
            ?>
                </div>
            </div>
        </div>
        <?php
    }

    public function page_init() {        
        register_setting(
            'simple_price_list_option_main', 
            'simple_price_list_options', 
            array( $this, 'sanitize' ) 
        );

        add_settings_section(
            'simple_price_list_settings_main', 
            __('Simple price list default settings', 'simple-price-list'), 
            array( $this, 'print_section_info' ), 
            'simple-price-list-setting-admin' 
        );  

        add_settings_field(
            'image', 
            __('Show image', 'simple-price-list'), 
            array( $this, 'image_callback' ), 
            'simple-price-list-setting-admin', 
            'simple_price_list_settings_main' 
        );

        add_settings_field(
            'group', 
            __('Groupped', 'simple-price-list'), 
            array( $this, 'group_callback' ), 
            'simple-price-list-setting-admin', 
            'simple_price_list_settings_main' 
        );

        add_settings_field(
            'exclude', 
            __('Exclude categoies', 'simple-price-list'), 
            array( $this, 'exclude_callback' ), 
            'simple-price-list-setting-admin', 
            'simple_price_list_settings_main' 
        );

        add_settings_field(
            'hide_out', 
            __('Hide out of stock', 'simple-price-list'), 
            array( $this, 'hide_out_callback' ), 
            'simple-price-list-setting-admin', 
            'simple_price_list_settings_main' 
        );

        add_settings_field(
            'out_of_stock_text', 
            __('"Out of stock" text', 'simple-price-list'), 
            array( $this, 'out_of_stock_text_callback' ), 
            'simple-price-list-setting-admin', 
            'simple_price_list_settings_main' 
        );


    }

    public function sanitize( $input ) {

        $new_input = array();

        if ( isset( $input['image'] ) ) {
            $new_input['image'] = $input['image'];
        } else {
            $new_input['image'] = 0;
        }
        if ( isset( $input['group'] ) ) {
            $new_input['group'] = $input['group'];
        } else {
            $new_input['group'] = 0;
        }
        if ( isset( $input['exclude'] ) ) {
            $new_input['exclude'] = implode(',', $input['exclude'] );
        }
        if ( isset( $input['hide_out'] ) ) {
            $new_input['hide_out'] = $input['hide_out'];
        } else {
            $new_input['hide_out'] = 0;
        }
        if ( isset( $input['out_of_stock_text'] ) ) {
            $new_input['out_of_stock_text'] = trim( $input['out_of_stock_text'] );
        }

        return $new_input;
    }

    public function print_section_info() {
        print __('These are the default settings. You can override these when calling Shortcode.', 'simple-price-list');
    }

    public function image_callback() {
        if ($this->options['image'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="simple_price_list_image" name="simple_price_list_options[image]" value="1" '.$checked.' />' .
            '<label for="simple_price_list_image"></label>' .
            '<small>'.__('Turn it on if you want the images to appear in the price list!', 'simple-price-list').'</small>',
            isset( $this->options['image'] ) ? esc_attr( $this->options['image']) : ''
        );
    }

    public function group_callback() {
        if ($this->options['group'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="simple_price_list_group" name="simple_price_list_options[group]" value="1" '.$checked.' />' .
            '<label for="simple_price_list_group"></label>' .
            '<small>'.__('Turn it on to display products grouped by category!', 'simple-price-list').'</small>',
            isset( $this->options['group'] ) ? esc_attr( $this->options['group']) : ''
        );
    }

    public function exclude_callback() {

        $selected = '';
        if (!empty($this->options['exclude'])) {
            $selected = $this->options['exclude'];    
        }

        $args = array(
            'hide_empty'  => false,
            'selected'    => $selected,
            'name'        => 'simple_price_list_options[exclude]',
            'id'          => 'simple_price_list_options_exclude',
            'orderby'     => 'NAME',
            'order'       => 'ASC',
            'show_option_none'   => __('None selected', 'simple-price-list'),
            'taxonomy'    => 'product_cat',
            'hierarchical'=> true,
            'echo'        => 0,
            'multiple'    => true
        );
        
        $dropdown = wp_dropdown_categories( $args );
        // $dropdown = apply_filters( 'wp_dropdown_cats', $dropdown, $selected);
        // $dropdown = str_replace('id=', 'multiple="multiple" id=', $dropdown);
        echo '<div style="margin:12px 0 0 0;padding:0;">'.$dropdown . 
             '<br /><small>'.__('Click in the box to select the categories you do not want to display in the list!', 'simple-price-list').'</small>'.
             '</div>';

    }

    public function hide_out_callback() {
        if ($this->options['hide_out'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="simple_price_list_hide_out" name="simple_price_list_options[hide_out]" value="1" '.$checked.' />' .
            '<label for="simple_price_list_hide_out"></label>' .
            '<small>'.__('Turn it on if you want only the product in stock to appear!', 'simple-price-list').'</small>',
            isset( $this->options['hide_out'] ) ? esc_attr( $this->options['hide_out']) : ''
        );
    }

    public function out_of_stock_text_callback() {
        printf(
            '<input type="text" name="simple_price_list_options[out_of_stock_text]" value="%s" />' .
            '<br /><small>'.__('This text is displayed when the product is out of stock.', 'simple-price-list').'</small>',
            isset( $this->options['out_of_stock_text'] ) ? esc_attr( $this->options['out_of_stock_text']) : ''
        );
    }

}

function simple_price_list_920_dropdown_cats_multiple( $output, $r ) {

    if( isset( $r['multiple'] ) && $r['multiple'] ) {

        $output = preg_replace( '/^<select/i', '<select multiple', $output );
        $output = str_replace( "name='{$r['name']}'", "name='{$r['name']}[]'", $output );
        foreach ( array_map( 'trim', explode( ",", $r['selected'] ) ) as $value ) {
            $output = str_replace( "value=\"{$value}\"", "value=\"{$value}\" selected", $output );
        }
    }

    return $output;
}    
add_filter( 'wp_dropdown_cats', 'simple_price_list_920_dropdown_cats_multiple', 10, 2 );

