<?php

if ( !defined( 'ABSPATH' ) ) exit;

function simple_price_list_920_shortcode_simple_price_list($args) {

	if (!in_array( 'woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
        $html = '<!-- SIMPLE PRICE LIST: WooCommerce not active -->';
        return $html;
    } 

	$options = simple_price_list_920_get_options();
    $args = wp_parse_args($args, $options);
    
    $args['template'] = 'default';

    $my_plugin = new JSimplePriceList920_simple_price_list($args);

    $html = $my_plugin->prepareContent();
    
    return $html;
}
add_shortcode('simple-price-list', 'simple_price_list_920_shortcode_simple_price_list');

class JSimplePriceList920_simple_price_list extends stdClass {
    private $options = null;
    private $data = array('categories' => array(), 'products' => array());
    private $woo_unit = '';
    
    public function __construct($options) {

        $this->options = $options;

        $this->woo_unit = get_option('woocommerce_weight_unit');

        $category = null;
        if ((isset($this->options['category'])) and (!empty($this->options['category']))) {
            $category = $this->options['category'];
        }

        if ($this->options['group'] == 0) {
            $this->data['products'] = $this->getAllProducts($category);
        } else {

            $this->data['categories'] = $this->getProductCategories($category);
            if (empty($category)) {
                $this->data['products'] = $this->getEmptyCategoryProducts();
            } else {
                $cat = get_term_by( 'id', $category, 'product_cat' );

                $this->data['id'] = $category;
                $this->data['name'] = $cat->name;
                $this->data['description'] = $cat->description;
                                
                $this->data['products'] = $this->getAllProducts($category);
            }
        }
    }

    private function getProductCategories($parent = null) {
    
        $result = array();

        if (!empty($parent)) {
            $cat_args = array(
                'taxonomy'   => 'product_cat',
                'hide_empty' => true,
                'parent'     => $parent, 
                'exclude'   => explode(',', $this->options['exclude'])
            );
        } else {
            $cat_args = array(
                'taxonomy'   => 'product_cat',
                'hide_empty' => true,
                'exclude'   => explode(',', $this->options['exclude'])
            );
        }
        $child_categories = get_terms($cat_args);
        
        foreach ($child_categories as $category) {
            $result[] = array(
                    'id'          => $category->term_id,
                    'name'        => $category->name,
                    'description' => $category->description,
                    'categories'  => $this->getProductCategories($category->term_id),
                    'products'    => $this->getAllProducts($category->term_id)
                );
        }
        
        return $result;
    }

    private function getEmptyCategoryProducts() {
        
        $result = array();

        $ids = get_posts( array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'numberposts' => -1,
            'fields'      => 'ids',
            'orderby'     => array('title' => 'ASC'),
            'tax_query' => array( 
                 array(
                    'taxonomy' => 'product_cat',
                    'field' => 'term_id',
                    'operator' => 'NOT IN',
                    'terms' => get_terms('product_cat', array(
                        'fields' => 'ids'
                        ))
                    )
                 )
            ));            
        
        foreach ($ids as $id) {
            $item = $this->getProduct($id);
            if (!empty($item)) {
                $result[] = $item;
            }
        }

        return $result;
        
    }

    private function getProduct($id) {
        
        $product = wc_get_product($id);

        if ($this->options['image']) {
            $image_id  = $product->get_image_id();
            $image_url = wp_get_attachment_image_url( $image_id, 'thumbnail' );
        } else {
            $image_url = '';
        }

        $result = array(
                'id'     => $id,
                'image'  => $image_url,
                'name'   => $product->get_name(),  
                'type'   => $product->get_type(),
                'status' => $product->get_stock_status(), 
                'url'    => get_permalink($id)             
            );
            
        $type = $product->get_type();
        if ($type == 'simple') {
            $weight = $product->get_weight();
            if (!empty($weight)) {
                $weight = apply_filters('simple_price_list_filter_weigth', $weight, $this->woo_unit);
                $result['weight'] = $weight;
            }
            $result['price'] = $product->get_price();
            $result['price_html'] = apply_filters('simple_price_list_filter_price', $product->get_price_html());
        }

        if ($type == 'variable') {
            $outofstock = true;

            $args = array(
                'post_type'     => 'product_variation',
                'post_status'   => array( 'publish' ),
                'numberposts'   => -1,
                'orderby'       => 'menu_order',
                'order'         => 'asc',
                'post_parent'   => $id
            );
            $childs = get_posts( $args ); 
            foreach ($childs as $item) {

                $p = wc_get_product($item->ID);
                
                $weight = $p->get_weight();

                $status = 1; $out_of_stock_text = '';
                if ($p->get_stock_status() == 'outofstock') { 
                    $status = 0;
                    $out_of_stock_text = $this->options['out_of_stock_text']; 
                } else {
                    $outofstock = false;    
                }

                if (($this->options['hide_out'] == 0) or ($status == 1))  {
                    $variations[] = array(
                            'name'        => $item->post_excerpt,  
                            'in_stock'    => $status,     
                            'price'       => $p->get_price(),
                            'price_html'  => apply_filters('simple_price_list_filter_price', $p->get_price_html()),
                            'weight'      => $weight,  
                            'weight_html' => apply_filters('simple_price_list_filter_weigth', $weight, $this->woo_unit),  
                            'outofstock'  => $out_of_stock_text
                        );                          
                }
            }
            $result['variations'] = $variations;
            if ($outofstock) {
                $result['status'] = 'outofstock';
            }
        }
        
        if (($this->options['hide_out']) and ($result['status'] == 'outofstock')) {
            return null;
        } 


        $result['in_stock'] = 1; $result['outofstock'] = '';
        if ($result['status'] == 'outofstock') { 
            $result['in_stock'] = 0; 
            $result['outofstock'] = $this->options['out_of_stock_text'];
        }
        unset($result['status']);
        
        return $result;
    }


    private function getAllProducts($category = null) {
        
        $result = array();

        $tax = array();
        
        if (!empty($category)) {
            $tax[] = array(
                    'taxonomy' => 'product_cat',
                    'field'    => 'term_id',
                    'terms'    => $category,
                    'operator' => 'IN'
                );
        }

        if (!empty($this->options['exclude'])) {
            $tax[] = array(
                    'taxonomy' => 'product_cat',
                    'field'    => 'term_id',
                    'terms'    => explode(',', $this->options['exclude']),
                    'operator' => 'NOT IN'
                );
        }

        $ids = get_posts( array(
                'post_type'   => 'product',
                'numberposts' => -1,
                'post_status' => 'publish',
                'fields'      => 'ids',
                'orderby'     => array('title' => 'ASC'),
                'tax_query'   => $tax
            ));
        
        foreach ($ids as $id) {
            $item = $this->getProduct($id);
            if (!empty($item)) {
                $result[] = $item;
            }
        }

        return $result;
    }

    function prepareContent() {   

        if (!class_exists('JDovi42_Templates')) {
            include_once(SIMPLE_PRICE_LIST_920_ROOT .DIRECTORY_SEPARATOR.'libs'.DIRECTORY_SEPARATOR.'jdovi42_templates.php');
        }
        
        $tmpl = new JDovi42_Templates($this->options['template']); 
        if ($tmpl->checkTemplate()) {
            $tmpl->setOptions($this->data);
            $html = $tmpl->prepareContent();
        } else {
            $html = '<!-- SIMPLE PRICE LIST: Template not found ('.$this->options['template'].') -->'; 
        }
        
        $html = "\r\n" .
                '<div class="simple-price-list">' . "\r\n" .
                      $html .  
                '</div>' . "\r\n";
                 
        return $html;
    }
    
}
    